==> vala-0.4.0.tar.bz2: vala-0.4.0/ccode/valaccodeifstatement.c <==
/* valaccodeifstatement.vala
 *
 * Copyright (C) 2006-2008  Jürg Billeter
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.

 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.

 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301  USA
 *
 * Author:
 * 	Jürg Billeter <j@bitron.ch>
 */

#include <ccode/valaccodeifstatement.h>
#include <stdlib.h>
#include <string.h>
#include <ccode/valaccodenode.h>
#include <ccode/valaccodelinedirective.h>
#include <ccode/valaccodeblock.h>




struct _ValaCCodeIfStatementPrivate {
	ValaCCodeExpression* _condition;
	ValaCCodeStatement* _true_statement;
	ValaCCodeStatement* _false_statement;
	gboolean _else_if;
};

#define VALA_CCODE_IF_STATEMENT_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), VALA_TYPE_CCODE_IF_STATEMENT, ValaCCodeIfStatementPrivate))
enum  {
	VALA_CCODE_IF_STATEMENT_DUMMY_PROPERTY
};
static void vala_ccode_if_statement_real_write (ValaCCodeNode* base, ValaCCodeWriter* writer);
static gpointer vala_ccode_if_statement_parent_class = NULL;
static void vala_ccode_if_statement_finalize (ValaCCodeNode* obj);



ValaCCodeIfStatement* vala_ccode_if_statement_construct (GType object_type, ValaCCodeExpression* cond, ValaCCodeStatement* true_stmt, ValaCCodeStatement* false_stmt) {
	ValaCCodeIfStatement* self;
	g_return_val_if_fail (VALA_IS_CCODE_EXPRESSION (cond), NULL);
	g_return_val_if_fail (VALA_IS_CCODE_STATEMENT (true_stmt), NULL);
	g_return_val_if_fail (false_stmt == NULL || VALA_IS_CCODE_STATEMENT (false_stmt), NULL);
	self = ((ValaCCodeIfStatement*) (g_type_create_instance (object_type)));
	vala_ccode_if_statement_set_condition (self, cond);
	vala_ccode_if_statement_set_true_statement (self, true_stmt);
	vala_ccode_if_statement_set_false_statement (self, false_stmt);
	return self;
}


ValaCCodeIfStatement* vala_ccode_if_statement_new (ValaCCodeExpression* cond, ValaCCodeStatement* true_stmt, ValaCCodeStatement* false_stmt) {
	return vala_ccode_if_statement_construct (VALA_TYPE_CCODE_IF_STATEMENT, cond, true_stmt, false_stmt);
}


static void vala_ccode_if_statement_real_write (ValaCCodeNode* base, ValaCCodeWriter* writer) {
	ValaCCodeIfStatement * self;
	self = VALA_CCODE_IF_STATEMENT (base);
	g_return_if_fail (VALA_IS_CCODE_WRITER (writer));
	if (!self->priv->_else_if) {
		vala_ccode_writer_write_indent (writer, vala_ccode_node_get_line (VALA_CCODE_NODE (self)));
	} else {
		vala_ccode_writer_write_string (writer, " ");
	}
	vala_ccode_writer_write_string (writer, "if (");
	if (self->priv->_condition != NULL) {
		vala_ccode_node_write (VALA_CCODE_NODE (self->priv->_condition), writer);
	}
	vala_ccode_writer_write_string (writer, ")");
	/* else shouldn't be on a separate line */
	if (self->priv->_false_statement != NULL && VALA_IS_CCODE_BLOCK (self->priv->_true_statement)) {
		ValaCCodeBlock* _tmp0;
		ValaCCodeBlock* cblock;
		_tmp0 = NULL;
		cblock = (_tmp0 = VALA_CCODE_BLOCK (self->priv->_true_statement), (_tmp0 == NULL ? NULL : vala_ccode_node_ref (_tmp0)));
		vala_ccode_block_set_suppress_newline (cblock, TRUE);
		(cblock == NULL ? NULL : (cblock = (vala_ccode_node_unref (cblock), NULL)));
	}
	vala_ccode_node_write (VALA_CCODE_NODE (self->priv->_true_statement), writer);
	if (self->priv->_false_statement != NULL) {
		if (vala_ccode_writer_get_bol (writer)) {
			vala_ccode_writer_write_indent (writer, NULL);
			vala_ccode_writer_write_string (writer, "else");
		} else {
			vala_ccode_writer_write_string (writer, " else");
		}
		/* else if should be on one line */
		if (VALA_IS_CCODE_IF_STATEMENT (self->priv->_false_statement)) {
			ValaCCodeIfStatement* _tmp1;
			ValaCCodeIfStatement* cif;
			_tmp1 = NULL;
			cif = (_tmp1 = VALA_CCODE_IF_STATEMENT (self->priv->_false_statement), (_tmp1 == NULL ? NULL : vala_ccode_node_ref (_tmp1)));
			vala_ccode_if_statement_set_else_if (cif, TRUE);
			(cif == NULL ? NULL : (cif = (vala_ccode_node_unref (cif), NULL)));
		}
		vala_ccode_node_write (VALA_CCODE_NODE (self->priv->_false_statement), writer);
	}
}


ValaCCodeExpression* vala_ccode_if_statement_get_condition (ValaCCodeIfStatement* self) {
	g_return_val_if_fail (VALA_IS_CCODE_IF_STATEMENT (self), NULL);
	return self->priv->_condition;
}


void vala_ccode_if_statement_set_condition (ValaCCodeIfStatement* self, ValaCCodeExpression* value) {
	ValaCCodeExpression* _tmp2;
	ValaCCodeExpression* _tmp1;
	g_return_if_fail (VALA_IS_CCODE_IF_STATEMENT (self));
	_tmp2 = NULL;
	_tmp1 = NULL;
	self->priv->_condition = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : vala_ccode_node_ref (_tmp1))), (self->priv->_condition == NULL ? NULL : (self->priv->_condition = (vala_ccode_node_unref (self->priv->_condition), NULL))), _tmp2);
}


ValaCCodeStatement* vala_ccode_if_statement_get_true_statement (ValaCCodeIfStatement* self) {
	g_return_val_if_fail (VALA_IS_CCODE_IF_STATEMENT (self), NULL);
	return self->priv->_true_statement;
}


void vala_ccode_if_statement_set_true_statement (ValaCCodeIfStatement* self, ValaCCodeStatement* value) {
	ValaCCodeStatement* _tmp2;
	ValaCCodeStatement* _tmp1;
	g_return_if_fail (VALA_IS_CCODE_IF_STATEMENT (self));
	_tmp2 = NULL;
	_tmp1 = NULL;
	self->priv->_true_statement = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : vala_ccode_node_ref (_tmp1))), (self->priv->_true_statement == NULL ? NULL : (self->priv->_true_statement = (vala_ccode_node_unref (self->priv->_true_statement), NULL))), _tmp2);
}


ValaCCodeStatement* vala_ccode_if_statement_get_false_statement (ValaCCodeIfStatement* self) {
	g_return_val_if_fail (VALA_IS_CCODE_IF_STATEMENT (self), NULL);
	return self->priv->_false_statement;
}


void vala_ccode_if_statement_set_false_statement (ValaCCodeIfStatement* self, ValaCCodeStatement* value) {
	ValaCCodeStatement* _tmp2;
	ValaCCodeStatement* _tmp1;
	g_return_if_fail (VALA_IS_CCODE_IF_STATEMENT (self));
	_tmp2 = NULL;
	_tmp1 = NULL;
	self->priv->_false_statement = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : vala_ccode_node_ref (_tmp1))), (self->priv->_false_statement == NULL ? NULL : (self->priv->_false_statement = (vala_ccode_node_unref (self->priv->_false_statement), NULL))), _tmp2);
}


gboolean vala_ccode_if_statement_get_else_if (ValaCCodeIfStatement* self) {
	g_return_val_if_fail (VALA_IS_CCODE_IF_STATEMENT (self), FALSE);
	return self->priv->_else_if;
}


void vala_ccode_if_statement_set_else_if (ValaCCodeIfStatement* self, gboolean value) {
	g_return_if_fail (VALA_IS_CCODE_IF_STATEMENT (self));
	self->priv->_else_if = value;
}


static void vala_ccode_if_statement_class_init (ValaCCodeIfStatementClass * klass) {
	vala_ccode_if_statement_parent_class = g_type_class_peek_parent (klass);
	VALA_CCODE_NODE_CLASS (klass)->finalize = vala_ccode_if_statement_finalize;
	g_type_class_add_private (klass, sizeof (ValaCCodeIfStatementPrivate));
	VALA_CCODE_NODE_CLASS (klass)->write = vala_ccode_if_statement_real_write;
}


static void vala_ccode_if_statement_instance_init (ValaCCodeIfStatement * self) {
	self->priv = VALA_CCODE_IF_STATEMENT_GET_PRIVATE (self);
}


static void vala_ccode_if_statement_finalize (ValaCCodeNode* obj) {
	ValaCCodeIfStatement * self;
	self = VALA_CCODE_IF_STATEMENT (obj);
	(self->priv->_condition == NULL ? NULL : (self->priv->_condition = (vala_ccode_node_unref (self->priv->_condition), NULL)));
	(self->priv->_true_statement == NULL ? NULL : (self->priv->_true_statement = (vala_ccode_node_unref (self->priv->_true_statement), NULL)));
	(self->priv->_false_statement == NULL ? NULL : (self->priv->_false_statement = (vala_ccode_node_unref (self->priv->_false_statement), NULL)));
	VALA_CCODE_NODE_CLASS (vala_ccode_if_statement_parent_class)->finalize (obj);
}


GType vala_ccode_if_statement_get_type (void) {
	static GType vala_ccode_if_statement_type_id = 0;
	if (vala_ccode_if_statement_type_id == 0) {
		static const GTypeInfo g_define_type_info = { sizeof (ValaCCodeIfStatementClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_ccode_if_statement_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaCCodeIfStatement), 0, (GInstanceInitFunc) vala_ccode_if_statement_instance_init, NULL };
		vala_ccode_if_statement_type_id = g_type_register_static (VALA_TYPE_CCODE_STATEMENT, "ValaCCodeIfStatement", &g_define_type_info, 0);
	}
	return vala_ccode_if_statement_type_id;
}

==> vala-0.5.1.tar.bz2: vala-0.5.1/ccode/valaccodeifstatement.c <==
/* valaccodeifstatement.vala
 *
 * Copyright (C) 2006-2008  Jürg Billeter
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.

 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.

 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301  USA
 *
 * Author:
 * 	Jürg Billeter <j@bitron.ch>
 */

#include <ccode/valaccodeifstatement.h>
#include <stdlib.h>
#include <string.h>
#include <ccode/valaccodenode.h>
#include <ccode/valaccodelinedirective.h>
#include <ccode/valaccodeblock.h>




struct _ValaCCodeIfStatementPrivate {
	ValaCCodeExpression* _condition;
	ValaCCodeStatement* _true_statement;
	ValaCCodeStatement* _false_statement;
	gboolean _else_if;
};

#define VALA_CCODE_IF_STATEMENT_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), VALA_TYPE_CCODE_IF_STATEMENT, ValaCCodeIfStatementPrivate))
enum  {
	VALA_CCODE_IF_STATEMENT_DUMMY_PROPERTY
};
static void vala_ccode_if_statement_real_write (ValaCCodeNode* base, ValaCCodeWriter* writer);
static gpointer vala_ccode_if_statement_parent_class = NULL;
static void vala_ccode_if_statement_finalize (ValaCCodeNode* obj);



ValaCCodeIfStatement* vala_ccode_if_statement_construct (GType object_type, ValaCCodeExpression* cond, ValaCCodeStatement* true_stmt, ValaCCodeStatement* false_stmt) {
	ValaCCodeIfStatement* self;
	g_return_val_if_fail (cond != NULL, NULL);
	g_return_val_if_fail (true_stmt != NULL, NULL);
	self = ((ValaCCodeIfStatement*) (g_type_create_instance (object_type)));
	vala_ccode_if_statement_set_condition (self, cond);
	vala_ccode_if_statement_set_true_statement (self, true_stmt);
	vala_ccode_if_statement_set_false_statement (self, false_stmt);
	return self;
}


ValaCCodeIfStatement* vala_ccode_if_statement_new (ValaCCodeExpression* cond, ValaCCodeStatement* true_stmt, ValaCCodeStatement* false_stmt) {
	return vala_ccode_if_statement_construct (VALA_TYPE_CCODE_IF_STATEMENT, cond, true_stmt, false_stmt);
}


static void vala_ccode_if_statement_real_write (ValaCCodeNode* base, ValaCCodeWriter* writer) {
	ValaCCodeIfStatement * self;
	self = ((ValaCCodeIfStatement*) (base));
	g_return_if_fail (writer != NULL);
	if (!self->priv->_else_if) {
		vala_ccode_writer_write_indent (writer, vala_ccode_node_get_line (((ValaCCodeNode*) (self))));
	} else {
		vala_ccode_writer_write_string (writer, " ");
	}
	vala_ccode_writer_write_string (writer, "if (");
	if (self->priv->_condition != NULL) {
		vala_ccode_node_write (((ValaCCodeNode*) (self->priv->_condition)), writer);
	}
	vala_ccode_writer_write_string (writer, ")");
	/* else shouldn't be on a separate line */
	if (self->priv->_false_statement != NULL && VALA_IS_CCODE_BLOCK (self->priv->_true_statement)) {
		ValaCCodeBlock* _tmp0;
		ValaCCodeBlock* cblock;
		_tmp0 = NULL;
		cblock = (_tmp0 = VALA_CCODE_BLOCK (self->priv->_true_statement), (_tmp0 == NULL ? NULL : vala_ccode_node_ref (_tmp0)));
		vala_ccode_block_set_suppress_newline (cblock, TRUE);
		(cblock == NULL ? NULL : (cblock = (vala_ccode_node_unref (cblock), NULL)));
	}
	vala_ccode_node_write (((ValaCCodeNode*) (self->priv->_true_statement)), writer);
	if (self->priv->_false_statement != NULL) {
		if (vala_ccode_writer_get_bol (writer)) {
			vala_ccode_writer_write_indent (writer, NULL);
			vala_ccode_writer_write_string (writer, "else");
		} else {
			vala_ccode_writer_write_string (writer, " else");
		}
		/* else if should be on one line */
		if (VALA_IS_CCODE_IF_STATEMENT (self->priv->_false_statement)) {
			ValaCCodeIfStatement* _tmp1;
			ValaCCodeIfStatement* cif;
			_tmp1 = NULL;
			cif = (_tmp1 = VALA_CCODE_IF_STATEMENT (self->priv->_false_statement), (_tmp1 == NULL ? NULL : vala_ccode_node_ref (_tmp1)));
			vala_ccode_if_statement_set_else_if (cif, TRUE);
			(cif == NULL ? NULL : (cif = (vala_ccode_node_unref (cif), NULL)));
		}
		vala_ccode_node_write (((ValaCCodeNode*) (self->priv->_false_statement)), writer);
	}
}


ValaCCodeExpression* vala_ccode_if_statement_get_condition (ValaCCodeIfStatement* self) {
	g_return_val_if_fail (self != NULL, NULL);
	return self->priv->_condition;
}


void vala_ccode_if_statement_set_condition (ValaCCodeIfStatement* self, ValaCCodeExpression* value) {
	ValaCCodeExpression* _tmp2;
	ValaCCodeExpression* _tmp1;
	g_return_if_fail (self != NULL);
	_tmp2 = NULL;
	_tmp1 = NULL;
	self->priv->_condition = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : vala_ccode_node_ref (_tmp1))), (self->priv->_condition == NULL ? NULL : (self->priv->_condition = (vala_ccode_node_unref (self->priv->_condition), NULL))), _tmp2);
}


ValaCCodeStatement* vala_ccode_if_statement_get_true_statement (ValaCCodeIfStatement* self) {
	g_return_val_if_fail (self != NULL, NULL);
	return self->priv->_true_statement;
}


void vala_ccode_if_statement_set_true_statement (ValaCCodeIfStatement* self, ValaCCodeStatement* value) {
	ValaCCodeStatement* _tmp2;
	ValaCCodeStatement* _tmp1;
	g_return_if_fail (self != NULL);
	_tmp2 = NULL;
	_tmp1 = NULL;
	self->priv->_true_statement = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : vala_ccode_node_ref (_tmp1))), (self->priv->_true_statement == NULL ? NULL : (self->priv->_true_statement = (vala_ccode_node_unref (self->priv->_true_statement), NULL))), _tmp2);
}


ValaCCodeStatement* vala_ccode_if_statement_get_false_statement (ValaCCodeIfStatement* self) {
	g_return_val_if_fail (self != NULL, NULL);
	return self->priv->_false_statement;
}


void vala_ccode_if_statement_set_false_statement (ValaCCodeIfStatement* self, ValaCCodeStatement* value) {
	ValaCCodeStatement* _tmp2;
	ValaCCodeStatement* _tmp1;
	g_return_if_fail (self != NULL);
	_tmp2 = NULL;
	_tmp1 = NULL;
	self->priv->_false_statement = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : vala_ccode_node_ref (_tmp1))), (self->priv->_false_statement == NULL ? NULL : (self->priv->_false_statement = (vala_ccode_node_unref (self->priv->_false_statement), NULL))), _tmp2);
}


gboolean vala_ccode_if_statement_get_else_if (ValaCCodeIfStatement* self) {
	g_return_val_if_fail (self != NULL, FALSE);
	return self->priv->_else_if;
}


void vala_ccode_if_statement_set_else_if (ValaCCodeIfStatement* self, gboolean value) {
	g_return_if_fail (self != NULL);
	self->priv->_else_if = value;
}


static void vala_ccode_if_statement_class_init (ValaCCodeIfStatementClass * klass) {
	vala_ccode_if_statement_parent_class = g_type_class_peek_parent (klass);
	VALA_CCODE_NODE_CLASS (klass)->finalize = vala_ccode_if_statement_finalize;
	g_type_class_add_private (klass, sizeof (ValaCCodeIfStatementPrivate));
	VALA_CCODE_NODE_CLASS (klass)->write = vala_ccode_if_statement_real_write;
}


static void vala_ccode_if_statement_instance_init (ValaCCodeIfStatement * self) {
	self->priv = VALA_CCODE_IF_STATEMENT_GET_PRIVATE (self);
}


static void vala_ccode_if_statement_finalize (ValaCCodeNode* obj) {
	ValaCCodeIfStatement * self;
	self = VALA_CCODE_IF_STATEMENT (obj);
	(self->priv->_condition == NULL ? NULL : (self->priv->_condition = (vala_ccode_node_unref (self->priv->_condition), NULL)));
	(self->priv->_true_statement == NULL ? NULL : (self->priv->_true_statement = (vala_ccode_node_unref (self->priv->_true_statement), NULL)));
	(self->priv->_false_statement == NULL ? NULL : (self->priv->_false_statement = (vala_ccode_node_unref (self->priv->_false_statement), NULL)));
	VALA_CCODE_NODE_CLASS (vala_ccode_if_statement_parent_class)->finalize (obj);
}


GType vala_ccode_if_statement_get_type (void) {
	static GType vala_ccode_if_statement_type_id = 0;
	if (vala_ccode_if_statement_type_id == 0) {
		static const GTypeInfo g_define_type_info = { sizeof (ValaCCodeIfStatementClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_ccode_if_statement_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaCCodeIfStatement), 0, (GInstanceInitFunc) vala_ccode_if_statement_instance_init, NULL };
		vala_ccode_if_statement_type_id = g_type_register_static (VALA_TYPE_CCODE_STATEMENT, "ValaCCodeIfStatement", &g_define_type_info, 0);
	}
	return vala_ccode_if_statement_type_id;
}
